package com.dxhy.auth.config;

import lombok.Getter;
import lombok.Setter;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.context.annotation.Configuration;

/**
 * 用户中心认证：配置文件信息读取
 *
 * @author ZSC-DXHY
 * @date 创建时间: 2021-04-08 10:29
 */
@SuppressWarnings("AlibabaLowerCamelCaseVariableNaming")
@Getter
@Setter
@Configuration
@RefreshScope
public class UserCenterConfig {

    /**
     * 过滤器不拦截的URL,以逗号隔开
     */
    @Value("${dxhy.userCenter.excludedPaths:}")
    private String excludedPaths;

    /**
     * 调用大B用户信息服务URL
     */
    @Value("${dxhy.userCenter.bigB.interfaceUrl:}")
    private String bigBInterfaceUrl;

    /**
     * 大B用户信息失效时重定向地址
     */
    @Value("${dxhy.userCenter.bigB.redirectUrl:}")
    private String bigBRedirectUrl;

    /**
     * 大B用户退出登录URL
     */
    @Value("${dxhy.userCenter.bigB.logoutPath:}")
    private String bigBLogoutPath;

    /**
     * 大B 业务系统标识
     */
    @Value("${dxhy.userCenter.bigB.systemSign:JXXT}")
    private String systemSign;

    /**
     * 大B用户退出登录URL
     *
     * @return
     */
    public String configBigBLogoutPath() {
        return bigBLogoutPath;
    }


    /**
     * 过滤器不拦截的URL,以逗号隔开
     *
     * @return
     */
    public String configExcludedPaths() {
        return excludedPaths;
    }


    /**
     * 大B用户信息失效时重定向的地址
     *
     * @return
     */
    public String configBigBRedirectUrl() {
        return bigBRedirectUrl;
    }

    /**
     * 大B用户基本信息接口
     *
     * @return
     */
    public String getBasicUserInfourl() {
        return bigBInterfaceUrl+"/base/v1/getBasicUserInfo";
    }


    /**
     * 大B用户菜单接口
     *
     * @return
     */
    public String getUserMenuListUrl() {
        return bigBInterfaceUrl+"/base/v1/getMenuList";
    }

    /**
     * 导出文件时推送大B消息 接口
     * @return
     */
    public String getToBigBMesUrl() {
        return bigBInterfaceUrl+"/v2/notifyInfo/addNotify";
    }

    /**
     * 大B 校验用户token是否有效
     *
     * @return
     */
    public String checkToken() {
        return bigBInterfaceUrl+"/base/isLogin";
    }




}
